Release Notes — configaro 1.0.1 documentation

# Release Notes

## 1.0.1

### Changes

- documentation changes only

## 1.0.0

Initial release of configaro, a Python 3.6 configuration library that’s music to your ears.

- a single file library with minimal dependencies
- a simple, expressive API that is easy to use and gets out of your way
- one that allows for hierarchical config data with dot-addressable access
- one that allows for defaults and locals config modules
- project automation, documentation and test coverage